# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetDatabaseResult',
    'AwaitableGetDatabaseResult',
    'get_database',
    'get_database_output',
]

@pulumi.output_type
class GetDatabaseResult:
    """
    A collection of values returned by getDatabase.
    """
    def __init__(__self__, id=None, instance_id=None, managed=None, name=None, owner=None, region=None, size=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if instance_id and not isinstance(instance_id, str):
            raise TypeError("Expected argument 'instance_id' to be a str")
        pulumi.set(__self__, "instance_id", instance_id)
        if managed and not isinstance(managed, bool):
            raise TypeError("Expected argument 'managed' to be a bool")
        pulumi.set(__self__, "managed", managed)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if owner and not isinstance(owner, str):
            raise TypeError("Expected argument 'owner' to be a str")
        pulumi.set(__self__, "owner", owner)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if size and not isinstance(size, str):
            raise TypeError("Expected argument 'size' to be a str")
        pulumi.set(__self__, "size", size)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> _builtins.str:
        return pulumi.get(self, "instance_id")

    @_builtins.property
    @pulumi.getter
    def managed(self) -> _builtins.bool:
        """
        Whether the database is managed or not.
        """
        return pulumi.get(self, "managed")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def owner(self) -> _builtins.str:
        """
        The name of the owner of the database.
        """
        return pulumi.get(self, "owner")

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter
    def size(self) -> _builtins.str:
        """
        Size of the database (in bytes).
        """
        return pulumi.get(self, "size")


class AwaitableGetDatabaseResult(GetDatabaseResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDatabaseResult(
            id=self.id,
            instance_id=self.instance_id,
            managed=self.managed,
            name=self.name,
            owner=self.owner,
            region=self.region,
            size=self.size)


def get_database(instance_id: Optional[_builtins.str] = None,
                 name: Optional[_builtins.str] = None,
                 region: Optional[_builtins.str] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDatabaseResult:
    """
    Gets information about a database.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Get the database foobar hosted on instance id 11111111-1111-1111-1111-111111111111
    my_db = scaleway.databases.get_database(instance_id="11111111-1111-1111-1111-111111111111",
        name="foobar")
    ```


    :param _builtins.str instance_id: The RDB instance ID.
    :param _builtins.str name: The name of the RDB instance.
    """
    __args__ = dict()
    __args__['instanceId'] = instance_id
    __args__['name'] = name
    __args__['region'] = region
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('scaleway:databases/getDatabase:getDatabase', __args__, opts=opts, typ=GetDatabaseResult).value

    return AwaitableGetDatabaseResult(
        id=pulumi.get(__ret__, 'id'),
        instance_id=pulumi.get(__ret__, 'instance_id'),
        managed=pulumi.get(__ret__, 'managed'),
        name=pulumi.get(__ret__, 'name'),
        owner=pulumi.get(__ret__, 'owner'),
        region=pulumi.get(__ret__, 'region'),
        size=pulumi.get(__ret__, 'size'))
def get_database_output(instance_id: Optional[pulumi.Input[_builtins.str]] = None,
                        name: Optional[pulumi.Input[_builtins.str]] = None,
                        region: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDatabaseResult]:
    """
    Gets information about a database.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Get the database foobar hosted on instance id 11111111-1111-1111-1111-111111111111
    my_db = scaleway.databases.get_database(instance_id="11111111-1111-1111-1111-111111111111",
        name="foobar")
    ```


    :param _builtins.str instance_id: The RDB instance ID.
    :param _builtins.str name: The name of the RDB instance.
    """
    __args__ = dict()
    __args__['instanceId'] = instance_id
    __args__['name'] = name
    __args__['region'] = region
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('scaleway:databases/getDatabase:getDatabase', __args__, opts=opts, typ=GetDatabaseResult)
    return __ret__.apply(lambda __response__: GetDatabaseResult(
        id=pulumi.get(__response__, 'id'),
        instance_id=pulumi.get(__response__, 'instance_id'),
        managed=pulumi.get(__response__, 'managed'),
        name=pulumi.get(__response__, 'name'),
        owner=pulumi.get(__response__, 'owner'),
        region=pulumi.get(__response__, 'region'),
        size=pulumi.get(__response__, 'size')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ContainerDomainArgs', 'ContainerDomain']

@pulumi.input_type
class ContainerDomainArgs:
    def __init__(__self__, *,
                 container_id: pulumi.Input[_builtins.str],
                 hostname: pulumi.Input[_builtins.str],
                 region: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a ContainerDomain resource.
        :param pulumi.Input[_builtins.str] container_id: The unique identifier of the container.
        :param pulumi.Input[_builtins.str] hostname: The hostname with a CNAME record.
        :param pulumi.Input[_builtins.str] region: `region`) The region in which the container exists.
        """
        pulumi.set(__self__, "container_id", container_id)
        pulumi.set(__self__, "hostname", hostname)
        if region is not None:
            pulumi.set(__self__, "region", region)

    @_builtins.property
    @pulumi.getter(name="containerId")
    def container_id(self) -> pulumi.Input[_builtins.str]:
        """
        The unique identifier of the container.
        """
        return pulumi.get(self, "container_id")

    @container_id.setter
    def container_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "container_id", value)

    @_builtins.property
    @pulumi.getter
    def hostname(self) -> pulumi.Input[_builtins.str]:
        """
        The hostname with a CNAME record.
        """
        return pulumi.get(self, "hostname")

    @hostname.setter
    def hostname(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "hostname", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `region`) The region in which the container exists.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)


@pulumi.input_type
class _ContainerDomainState:
    def __init__(__self__, *,
                 container_id: Optional[pulumi.Input[_builtins.str]] = None,
                 hostname: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 url: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering ContainerDomain resources.
        :param pulumi.Input[_builtins.str] container_id: The unique identifier of the container.
        :param pulumi.Input[_builtins.str] hostname: The hostname with a CNAME record.
        :param pulumi.Input[_builtins.str] region: `region`) The region in which the container exists.
        :param pulumi.Input[_builtins.str] url: The URL used to query the container.
        """
        if container_id is not None:
            pulumi.set(__self__, "container_id", container_id)
        if hostname is not None:
            pulumi.set(__self__, "hostname", hostname)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if url is not None:
            pulumi.set(__self__, "url", url)

    @_builtins.property
    @pulumi.getter(name="containerId")
    def container_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The unique identifier of the container.
        """
        return pulumi.get(self, "container_id")

    @container_id.setter
    def container_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "container_id", value)

    @_builtins.property
    @pulumi.getter
    def hostname(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The hostname with a CNAME record.
        """
        return pulumi.get(self, "hostname")

    @hostname.setter
    def hostname(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "hostname", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `region`) The region in which the container exists.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter
    def url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The URL used to query the container.
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "url", value)


warnings.warn("""scaleway.index/containerdomain.ContainerDomain has been deprecated in favor of scaleway.containers/domain.Domain""", DeprecationWarning)


@pulumi.type_token("scaleway:index/containerDomain:ContainerDomain")
class ContainerDomain(pulumi.CustomResource):
    warnings.warn("""scaleway.index/containerdomain.ContainerDomain has been deprecated in favor of scaleway.containers/domain.Domain""", DeprecationWarning)

    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 container_id: Optional[pulumi.Input[_builtins.str]] = None,
                 hostname: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        The `containers.Domain` resource allows you to create and manage domain name bindings for Scaleway [Serverless Containers](https://www.scaleway.com/en/docs/serverless/containers/).

        Refer to the Containers domain [documentation](https://www.scaleway.com/en/docs/serverless-containers/how-to/add-a-custom-domain-to-a-container/) and the [API documentation](https://www.scaleway.com/en/developers/api/serverless-containers/#path-domains-list-all-domain-name-bindings) for more information.

        ## Example Usage

        The commands below shows how to bind a custom domain name to a container.

        ### Simple

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        app = scaleway.containers.Container("app")
        app_domain = scaleway.containers.Domain("app",
            container_id=app.id,
            hostname="container.domain.tld")
        ```

        ### Complete example with domain

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.containers.Namespace("main",
            name="my-ns-test",
            description="test container")
        app = scaleway.containers.Container("app",
            name="app",
            namespace_id=main.id,
            registry_image=main.registry_endpoint.apply(lambda registry_endpoint: f"{registry_endpoint}/nginx:alpine"),
            port=80,
            cpu_limit=140,
            memory_limit=256,
            min_scale=1,
            max_scale=1,
            timeout=600,
            max_concurrency=80,
            privacy="public",
            protocol="http1",
            deploy=True)
        app_record = scaleway.domain.Record("app",
            dns_zone="domain.tld",
            name="subdomain",
            type="CNAME",
            data=app.domain_name.apply(lambda domain_name: f"{domain_name}."),
            ttl=3600)
        app_domain = scaleway.containers.Domain("app",
            container_id=app.id,
            hostname=pulumi.Output.all(
                name=app_record.name,
                dns_zone=app_record.dns_zone
        ).apply(lambda resolved_outputs: f"{resolved_outputs['name']}.{resolved_outputs['dns_zone']}")
        )
        ```

        ## Import

        Container domain binding can be imported using `{region}/{id}`, as shown below:

        bash

        ```sh
        $ pulumi import scaleway:index/containerDomain:ContainerDomain main fr-par/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] container_id: The unique identifier of the container.
        :param pulumi.Input[_builtins.str] hostname: The hostname with a CNAME record.
        :param pulumi.Input[_builtins.str] region: `region`) The region in which the container exists.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ContainerDomainArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `containers.Domain` resource allows you to create and manage domain name bindings for Scaleway [Serverless Containers](https://www.scaleway.com/en/docs/serverless/containers/).

        Refer to the Containers domain [documentation](https://www.scaleway.com/en/docs/serverless-containers/how-to/add-a-custom-domain-to-a-container/) and the [API documentation](https://www.scaleway.com/en/developers/api/serverless-containers/#path-domains-list-all-domain-name-bindings) for more information.

        ## Example Usage

        The commands below shows how to bind a custom domain name to a container.

        ### Simple

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        app = scaleway.containers.Container("app")
        app_domain = scaleway.containers.Domain("app",
            container_id=app.id,
            hostname="container.domain.tld")
        ```

        ### Complete example with domain

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.containers.Namespace("main",
            name="my-ns-test",
            description="test container")
        app = scaleway.containers.Container("app",
            name="app",
            namespace_id=main.id,
            registry_image=main.registry_endpoint.apply(lambda registry_endpoint: f"{registry_endpoint}/nginx:alpine"),
            port=80,
            cpu_limit=140,
            memory_limit=256,
            min_scale=1,
            max_scale=1,
            timeout=600,
            max_concurrency=80,
            privacy="public",
            protocol="http1",
            deploy=True)
        app_record = scaleway.domain.Record("app",
            dns_zone="domain.tld",
            name="subdomain",
            type="CNAME",
            data=app.domain_name.apply(lambda domain_name: f"{domain_name}."),
            ttl=3600)
        app_domain = scaleway.containers.Domain("app",
            container_id=app.id,
            hostname=pulumi.Output.all(
                name=app_record.name,
                dns_zone=app_record.dns_zone
        ).apply(lambda resolved_outputs: f"{resolved_outputs['name']}.{resolved_outputs['dns_zone']}")
        )
        ```

        ## Import

        Container domain binding can be imported using `{region}/{id}`, as shown below:

        bash

        ```sh
        $ pulumi import scaleway:index/containerDomain:ContainerDomain main fr-par/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param ContainerDomainArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ContainerDomainArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 container_id: Optional[pulumi.Input[_builtins.str]] = None,
                 hostname: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        pulumi.log.warn("""ContainerDomain is deprecated: scaleway.index/containerdomain.ContainerDomain has been deprecated in favor of scaleway.containers/domain.Domain""")
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ContainerDomainArgs.__new__(ContainerDomainArgs)

            if container_id is None and not opts.urn:
                raise TypeError("Missing required property 'container_id'")
            __props__.__dict__["container_id"] = container_id
            if hostname is None and not opts.urn:
                raise TypeError("Missing required property 'hostname'")
            __props__.__dict__["hostname"] = hostname
            __props__.__dict__["region"] = region
            __props__.__dict__["url"] = None
        super(ContainerDomain, __self__).__init__(
            'scaleway:index/containerDomain:ContainerDomain',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            container_id: Optional[pulumi.Input[_builtins.str]] = None,
            hostname: Optional[pulumi.Input[_builtins.str]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None,
            url: Optional[pulumi.Input[_builtins.str]] = None) -> 'ContainerDomain':
        """
        Get an existing ContainerDomain resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] container_id: The unique identifier of the container.
        :param pulumi.Input[_builtins.str] hostname: The hostname with a CNAME record.
        :param pulumi.Input[_builtins.str] region: `region`) The region in which the container exists.
        :param pulumi.Input[_builtins.str] url: The URL used to query the container.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ContainerDomainState.__new__(_ContainerDomainState)

        __props__.__dict__["container_id"] = container_id
        __props__.__dict__["hostname"] = hostname
        __props__.__dict__["region"] = region
        __props__.__dict__["url"] = url
        return ContainerDomain(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="containerId")
    def container_id(self) -> pulumi.Output[_builtins.str]:
        """
        The unique identifier of the container.
        """
        return pulumi.get(self, "container_id")

    @_builtins.property
    @pulumi.getter
    def hostname(self) -> pulumi.Output[_builtins.str]:
        """
        The hostname with a CNAME record.
        """
        return pulumi.get(self, "hostname")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        `region`) The region in which the container exists.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter
    def url(self) -> pulumi.Output[_builtins.str]:
        """
        The URL used to query the container.
        """
        return pulumi.get(self, "url")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['VersionArgs', 'Version']

@pulumi.input_type
class VersionArgs:
    def __init__(__self__, *,
                 data: pulumi.Input[_builtins.str],
                 secret_id: pulumi.Input[_builtins.str],
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Version resource.
        :param pulumi.Input[_builtins.str] data: The data payload of the secret version. Must not exceed 64KiB in size (e.g. `my-secret-version-payload`). Find out more on the [data section](https://www.terraform.io/#data-information).
        :param pulumi.Input[_builtins.str] secret_id: The ID of the secret associated with the version.
        :param pulumi.Input[_builtins.str] description: Description of the secret version (e.g. `my-new-description`).
        :param pulumi.Input[_builtins.str] region: ). The region where the resource exists.
        """
        pulumi.set(__self__, "data", data)
        pulumi.set(__self__, "secret_id", secret_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if region is not None:
            pulumi.set(__self__, "region", region)

    @_builtins.property
    @pulumi.getter
    def data(self) -> pulumi.Input[_builtins.str]:
        """
        The data payload of the secret version. Must not exceed 64KiB in size (e.g. `my-secret-version-payload`). Find out more on the [data section](https://www.terraform.io/#data-information).
        """
        return pulumi.get(self, "data")

    @data.setter
    def data(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "data", value)

    @_builtins.property
    @pulumi.getter(name="secretId")
    def secret_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the secret associated with the version.
        """
        return pulumi.get(self, "secret_id")

    @secret_id.setter
    def secret_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "secret_id", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the secret version (e.g. `my-new-description`).
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ). The region where the resource exists.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)


@pulumi.input_type
class _VersionState:
    def __init__(__self__, *,
                 created_at: Optional[pulumi.Input[_builtins.str]] = None,
                 data: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 revision: Optional[pulumi.Input[_builtins.str]] = None,
                 secret_id: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 updated_at: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Version resources.
        :param pulumi.Input[_builtins.str] created_at: The date and time of the secret version's creation (in RFC 3339 format).
        :param pulumi.Input[_builtins.str] data: The data payload of the secret version. Must not exceed 64KiB in size (e.g. `my-secret-version-payload`). Find out more on the [data section](https://www.terraform.io/#data-information).
        :param pulumi.Input[_builtins.str] description: Description of the secret version (e.g. `my-new-description`).
        :param pulumi.Input[_builtins.str] region: ). The region where the resource exists.
        :param pulumi.Input[_builtins.str] revision: The revision number of the secret version.
        :param pulumi.Input[_builtins.str] secret_id: The ID of the secret associated with the version.
        :param pulumi.Input[_builtins.str] status: The status of the secret version.
        :param pulumi.Input[_builtins.str] updated_at: The date and time of the secret version's last update (in RFC 3339 format).
        """
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if data is not None:
            pulumi.set(__self__, "data", data)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if revision is not None:
            pulumi.set(__self__, "revision", revision)
        if secret_id is not None:
            pulumi.set(__self__, "secret_id", secret_id)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date and time of the secret version's creation (in RFC 3339 format).
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created_at", value)

    @_builtins.property
    @pulumi.getter
    def data(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The data payload of the secret version. Must not exceed 64KiB in size (e.g. `my-secret-version-payload`). Find out more on the [data section](https://www.terraform.io/#data-information).
        """
        return pulumi.get(self, "data")

    @data.setter
    def data(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "data", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the secret version (e.g. `my-new-description`).
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ). The region where the resource exists.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter
    def revision(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The revision number of the secret version.
        """
        return pulumi.get(self, "revision")

    @revision.setter
    def revision(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "revision", value)

    @_builtins.property
    @pulumi.getter(name="secretId")
    def secret_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the secret associated with the version.
        """
        return pulumi.get(self, "secret_id")

    @secret_id.setter
    def secret_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "secret_id", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The status of the secret version.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date and time of the secret version's last update (in RFC 3339 format).
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "updated_at", value)


@pulumi.type_token("scaleway:secrets/version:Version")
class Version(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 data: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 secret_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        The `secrets.Version` resource allows you to create and manage secret versions in Scaleway Secret Manager.

        Refer to the Secret Manager [product documentation](https://www.scaleway.com/en/docs/secret-manager/) and [API documentation](https://www.scaleway.com/en/developers/api/secret-manager/) for more information.

        ## Example Usage

        ### Create a secret and a version

        The following commands allow you to:

        - create a secret named `foo`
        - create a version of this secret containing the `my_new_secret` data

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.secrets.Secret("main",
            name="foo",
            description="barr",
            tags=[
                "foo",
                "terraform",
            ])
        v1 = scaleway.secrets.Version("v1",
            description="version1",
            secret_id=main.id,
            data="my_new_secret")
        ```

        ## Import

        This section explains how to import a secret version using the `{region}/{id}/{revision}` format.

        ~> **Important:** Keep in mind that if you import with the `latest` revision, you will overwrite the previous version you might have been using.

        bash

        ```sh
        $ pulumi import scaleway:secrets/version:Version main fr-par/11111111-1111-1111-1111-111111111111/2
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] data: The data payload of the secret version. Must not exceed 64KiB in size (e.g. `my-secret-version-payload`). Find out more on the [data section](https://www.terraform.io/#data-information).
        :param pulumi.Input[_builtins.str] description: Description of the secret version (e.g. `my-new-description`).
        :param pulumi.Input[_builtins.str] region: ). The region where the resource exists.
        :param pulumi.Input[_builtins.str] secret_id: The ID of the secret associated with the version.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: VersionArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `secrets.Version` resource allows you to create and manage secret versions in Scaleway Secret Manager.

        Refer to the Secret Manager [product documentation](https://www.scaleway.com/en/docs/secret-manager/) and [API documentation](https://www.scaleway.com/en/developers/api/secret-manager/) for more information.

        ## Example Usage

        ### Create a secret and a version

        The following commands allow you to:

        - create a secret named `foo`
        - create a version of this secret containing the `my_new_secret` data

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.secrets.Secret("main",
            name="foo",
            description="barr",
            tags=[
                "foo",
                "terraform",
            ])
        v1 = scaleway.secrets.Version("v1",
            description="version1",
            secret_id=main.id,
            data="my_new_secret")
        ```

        ## Import

        This section explains how to import a secret version using the `{region}/{id}/{revision}` format.

        ~> **Important:** Keep in mind that if you import with the `latest` revision, you will overwrite the previous version you might have been using.

        bash

        ```sh
        $ pulumi import scaleway:secrets/version:Version main fr-par/11111111-1111-1111-1111-111111111111/2
        ```

        :param str resource_name: The name of the resource.
        :param VersionArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(VersionArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 data: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 secret_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = VersionArgs.__new__(VersionArgs)

            if data is None and not opts.urn:
                raise TypeError("Missing required property 'data'")
            __props__.__dict__["data"] = None if data is None else pulumi.Output.secret(data)
            __props__.__dict__["description"] = description
            __props__.__dict__["region"] = region
            if secret_id is None and not opts.urn:
                raise TypeError("Missing required property 'secret_id'")
            __props__.__dict__["secret_id"] = secret_id
            __props__.__dict__["created_at"] = None
            __props__.__dict__["revision"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["updated_at"] = None
        alias_opts = pulumi.ResourceOptions(aliases=[pulumi.Alias(type_="scaleway:index/secretVersion:SecretVersion")])
        opts = pulumi.ResourceOptions.merge(opts, alias_opts)
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["data"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(Version, __self__).__init__(
            'scaleway:secrets/version:Version',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            created_at: Optional[pulumi.Input[_builtins.str]] = None,
            data: Optional[pulumi.Input[_builtins.str]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None,
            revision: Optional[pulumi.Input[_builtins.str]] = None,
            secret_id: Optional[pulumi.Input[_builtins.str]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None,
            updated_at: Optional[pulumi.Input[_builtins.str]] = None) -> 'Version':
        """
        Get an existing Version resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] created_at: The date and time of the secret version's creation (in RFC 3339 format).
        :param pulumi.Input[_builtins.str] data: The data payload of the secret version. Must not exceed 64KiB in size (e.g. `my-secret-version-payload`). Find out more on the [data section](https://www.terraform.io/#data-information).
        :param pulumi.Input[_builtins.str] description: Description of the secret version (e.g. `my-new-description`).
        :param pulumi.Input[_builtins.str] region: ). The region where the resource exists.
        :param pulumi.Input[_builtins.str] revision: The revision number of the secret version.
        :param pulumi.Input[_builtins.str] secret_id: The ID of the secret associated with the version.
        :param pulumi.Input[_builtins.str] status: The status of the secret version.
        :param pulumi.Input[_builtins.str] updated_at: The date and time of the secret version's last update (in RFC 3339 format).
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _VersionState.__new__(_VersionState)

        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["data"] = data
        __props__.__dict__["description"] = description
        __props__.__dict__["region"] = region
        __props__.__dict__["revision"] = revision
        __props__.__dict__["secret_id"] = secret_id
        __props__.__dict__["status"] = status
        __props__.__dict__["updated_at"] = updated_at
        return Version(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[_builtins.str]:
        """
        The date and time of the secret version's creation (in RFC 3339 format).
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter
    def data(self) -> pulumi.Output[_builtins.str]:
        """
        The data payload of the secret version. Must not exceed 64KiB in size (e.g. `my-secret-version-payload`). Find out more on the [data section](https://www.terraform.io/#data-information).
        """
        return pulumi.get(self, "data")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Description of the secret version (e.g. `my-new-description`).
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        ). The region where the resource exists.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter
    def revision(self) -> pulumi.Output[_builtins.str]:
        """
        The revision number of the secret version.
        """
        return pulumi.get(self, "revision")

    @_builtins.property
    @pulumi.getter(name="secretId")
    def secret_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the secret associated with the version.
        """
        return pulumi.get(self, "secret_id")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[_builtins.str]:
        """
        The status of the secret version.
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[_builtins.str]:
        """
        The date and time of the secret version's last update (in RFC 3339 format).
        """
        return pulumi.get(self, "updated_at")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['PolicyArgs', 'Policy']

@pulumi.input_type
class PolicyArgs:
    def __init__(__self__, *,
                 rules: pulumi.Input[Sequence[pulumi.Input['PolicyRuleArgs']]],
                 application_id: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 group_id: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 no_principal: Optional[pulumi.Input[_builtins.bool]] = None,
                 organization_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 user_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Policy resource.
        :param pulumi.Input[Sequence[pulumi.Input['PolicyRuleArgs']]] rules: List of rules in the policy.
        :param pulumi.Input[_builtins.str] application_id: ID of the application the policy will be linked to
        :param pulumi.Input[_builtins.str] description: The description of the IAM policy.
        :param pulumi.Input[_builtins.str] group_id: ID of the group the policy will be linked to
        :param pulumi.Input[_builtins.str] name: The name of the IAM policy.
        :param pulumi.Input[_builtins.bool] no_principal: If the policy doesn't apply to a principal.
               
               > **Important** Only one of `user_id`, `group_id`, `application_id` and `no_principal` may be set.
        :param pulumi.Input[_builtins.str] organization_id: `organization_id`) The ID of the organization the policy is associated with.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: The tags associated with the IAM policy.
        :param pulumi.Input[_builtins.str] user_id: ID of the user the policy will be linked to
        """
        pulumi.set(__self__, "rules", rules)
        if application_id is not None:
            pulumi.set(__self__, "application_id", application_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if group_id is not None:
            pulumi.set(__self__, "group_id", group_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if no_principal is not None:
            pulumi.set(__self__, "no_principal", no_principal)
        if organization_id is not None:
            pulumi.set(__self__, "organization_id", organization_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if user_id is not None:
            pulumi.set(__self__, "user_id", user_id)

    @_builtins.property
    @pulumi.getter
    def rules(self) -> pulumi.Input[Sequence[pulumi.Input['PolicyRuleArgs']]]:
        """
        List of rules in the policy.
        """
        return pulumi.get(self, "rules")

    @rules.setter
    def rules(self, value: pulumi.Input[Sequence[pulumi.Input['PolicyRuleArgs']]]):
        pulumi.set(self, "rules", value)

    @_builtins.property
    @pulumi.getter(name="applicationId")
    def application_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of the application the policy will be linked to
        """
        return pulumi.get(self, "application_id")

    @application_id.setter
    def application_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "application_id", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The description of the IAM policy.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="groupId")
    def group_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of the group the policy will be linked to
        """
        return pulumi.get(self, "group_id")

    @group_id.setter
    def group_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "group_id", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the IAM policy.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="noPrincipal")
    def no_principal(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        If the policy doesn't apply to a principal.

        > **Important** Only one of `user_id`, `group_id`, `application_id` and `no_principal` may be set.
        """
        return pulumi.get(self, "no_principal")

    @no_principal.setter
    def no_principal(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "no_principal", value)

    @_builtins.property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `organization_id`) The ID of the organization the policy is associated with.
        """
        return pulumi.get(self, "organization_id")

    @organization_id.setter
    def organization_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "organization_id", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The tags associated with the IAM policy.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter(name="userId")
    def user_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of the user the policy will be linked to
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "user_id", value)


@pulumi.input_type
class _PolicyState:
    def __init__(__self__, *,
                 application_id: Optional[pulumi.Input[_builtins.str]] = None,
                 created_at: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 editable: Optional[pulumi.Input[_builtins.bool]] = None,
                 group_id: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 no_principal: Optional[pulumi.Input[_builtins.bool]] = None,
                 organization_id: Optional[pulumi.Input[_builtins.str]] = None,
                 rules: Optional[pulumi.Input[Sequence[pulumi.Input['PolicyRuleArgs']]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 updated_at: Optional[pulumi.Input[_builtins.str]] = None,
                 user_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Policy resources.
        :param pulumi.Input[_builtins.str] application_id: ID of the application the policy will be linked to
        :param pulumi.Input[_builtins.str] created_at: The date and time of the creation of the policy.
        :param pulumi.Input[_builtins.str] description: The description of the IAM policy.
        :param pulumi.Input[_builtins.bool] editable: Whether the policy is editable.
        :param pulumi.Input[_builtins.str] group_id: ID of the group the policy will be linked to
        :param pulumi.Input[_builtins.str] name: The name of the IAM policy.
        :param pulumi.Input[_builtins.bool] no_principal: If the policy doesn't apply to a principal.
               
               > **Important** Only one of `user_id`, `group_id`, `application_id` and `no_principal` may be set.
        :param pulumi.Input[_builtins.str] organization_id: `organization_id`) The ID of the organization the policy is associated with.
        :param pulumi.Input[Sequence[pulumi.Input['PolicyRuleArgs']]] rules: List of rules in the policy.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: The tags associated with the IAM policy.
        :param pulumi.Input[_builtins.str] updated_at: The date and time of the last update of the policy.
        :param pulumi.Input[_builtins.str] user_id: ID of the user the policy will be linked to
        """
        if application_id is not None:
            pulumi.set(__self__, "application_id", application_id)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if editable is not None:
            pulumi.set(__self__, "editable", editable)
        if group_id is not None:
            pulumi.set(__self__, "group_id", group_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if no_principal is not None:
            pulumi.set(__self__, "no_principal", no_principal)
        if organization_id is not None:
            pulumi.set(__self__, "organization_id", organization_id)
        if rules is not None:
            pulumi.set(__self__, "rules", rules)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)
        if user_id is not None:
            pulumi.set(__self__, "user_id", user_id)

    @_builtins.property
    @pulumi.getter(name="applicationId")
    def application_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of the application the policy will be linked to
        """
        return pulumi.get(self, "application_id")

    @application_id.setter
    def application_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "application_id", value)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date and time of the creation of the policy.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created_at", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The description of the IAM policy.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def editable(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the policy is editable.
        """
        return pulumi.get(self, "editable")

    @editable.setter
    def editable(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "editable", value)

    @_builtins.property
    @pulumi.getter(name="groupId")
    def group_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of the group the policy will be linked to
        """
        return pulumi.get(self, "group_id")

    @group_id.setter
    def group_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "group_id", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the IAM policy.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="noPrincipal")
    def no_principal(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        If the policy doesn't apply to a principal.

        > **Important** Only one of `user_id`, `group_id`, `application_id` and `no_principal` may be set.
        """
        return pulumi.get(self, "no_principal")

    @no_principal.setter
    def no_principal(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "no_principal", value)

    @_builtins.property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `organization_id`) The ID of the organization the policy is associated with.
        """
        return pulumi.get(self, "organization_id")

    @organization_id.setter
    def organization_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "organization_id", value)

    @_builtins.property
    @pulumi.getter
    def rules(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['PolicyRuleArgs']]]]:
        """
        List of rules in the policy.
        """
        return pulumi.get(self, "rules")

    @rules.setter
    def rules(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['PolicyRuleArgs']]]]):
        pulumi.set(self, "rules", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The tags associated with the IAM policy.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date and time of the last update of the policy.
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "updated_at", value)

    @_builtins.property
    @pulumi.getter(name="userId")
    def user_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of the user the policy will be linked to
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "user_id", value)


@pulumi.type_token("scaleway:iam/policy:Policy")
class Policy(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 application_id: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 group_id: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 no_principal: Optional[pulumi.Input[_builtins.bool]] = None,
                 organization_id: Optional[pulumi.Input[_builtins.str]] = None,
                 rules: Optional[pulumi.Input[Sequence[pulumi.Input[Union['PolicyRuleArgs', 'PolicyRuleArgsDict']]]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 user_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Creates and manages Scaleway IAM Policies. For more information refer to the [IAM API documentation](https://www.scaleway.com/en/developers/api/iam/#path-policies-create-a-new-policy).

        > You can find a detailed list of all permission sets available at Scaleway in the permission sets [reference page](https://www.scaleway.com/en/docs/iam/reference-content/permission-sets/).

        ## Example Usage

        ### Create a policy for an organization's project

        ```python
        import pulumi
        import pulumi_scaleway as scaleway
        import pulumiverse_scaleway as scaleway

        default = scaleway.account.get_project(name="default")
        app = scaleway.iam.Application("app", name="my app")
        object_read_only = scaleway.iam.Policy("object_read_only",
            name="my policy",
            description="gives app readonly access to object storage in project",
            application_id=app.id,
            rules=[{
                "project_ids": [default.id],
                "permission_set_names": ["ObjectStorageReadOnly"],
            }])
        ```

        ### Create a policy for all current and future projects in an organization

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        app = scaleway.iam.Application("app", name="my app")
        object_read_only = scaleway.iam.Policy("object_read_only",
            name="my policy",
            description="gives app readonly access to object storage in project",
            application_id=app.id,
            rules=[{
                "organization_id": app.organization_id,
                "permission_set_names": ["ObjectStorageReadOnly"],
            }])
        ```

        ### Create a policy with a particular condition

        IAM policy rule can use a condition to be applied.
        The following variables are available:

        - `request.ip`
        - `request.user_agent`
        - `request.time`

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.iam.Policy("main",
            name="tf_tests_policy_condition",
            no_principal=True,
            rules=[{
                "organization_id": "%s",
                "permission_set_names": ["AllProductsFullAccess"],
                "condition": "request.user_agent == 'My User Agent'",
            }])
        ```

        ## Import

        Policies can be imported using the `{id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:iam/policy:Policy main 11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] application_id: ID of the application the policy will be linked to
        :param pulumi.Input[_builtins.str] description: The description of the IAM policy.
        :param pulumi.Input[_builtins.str] group_id: ID of the group the policy will be linked to
        :param pulumi.Input[_builtins.str] name: The name of the IAM policy.
        :param pulumi.Input[_builtins.bool] no_principal: If the policy doesn't apply to a principal.
               
               > **Important** Only one of `user_id`, `group_id`, `application_id` and `no_principal` may be set.
        :param pulumi.Input[_builtins.str] organization_id: `organization_id`) The ID of the organization the policy is associated with.
        :param pulumi.Input[Sequence[pulumi.Input[Union['PolicyRuleArgs', 'PolicyRuleArgsDict']]]] rules: List of rules in the policy.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: The tags associated with the IAM policy.
        :param pulumi.Input[_builtins.str] user_id: ID of the user the policy will be linked to
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: PolicyArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates and manages Scaleway IAM Policies. For more information refer to the [IAM API documentation](https://www.scaleway.com/en/developers/api/iam/#path-policies-create-a-new-policy).

        > You can find a detailed list of all permission sets available at Scaleway in the permission sets [reference page](https://www.scaleway.com/en/docs/iam/reference-content/permission-sets/).

        ## Example Usage

        ### Create a policy for an organization's project

        ```python
        import pulumi
        import pulumi_scaleway as scaleway
        import pulumiverse_scaleway as scaleway

        default = scaleway.account.get_project(name="default")
        app = scaleway.iam.Application("app", name="my app")
        object_read_only = scaleway.iam.Policy("object_read_only",
            name="my policy",
            description="gives app readonly access to object storage in project",
            application_id=app.id,
            rules=[{
                "project_ids": [default.id],
                "permission_set_names": ["ObjectStorageReadOnly"],
            }])
        ```

        ### Create a policy for all current and future projects in an organization

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        app = scaleway.iam.Application("app", name="my app")
        object_read_only = scaleway.iam.Policy("object_read_only",
            name="my policy",
            description="gives app readonly access to object storage in project",
            application_id=app.id,
            rules=[{
                "organization_id": app.organization_id,
                "permission_set_names": ["ObjectStorageReadOnly"],
            }])
        ```

        ### Create a policy with a particular condition

        IAM policy rule can use a condition to be applied.
        The following variables are available:

        - `request.ip`
        - `request.user_agent`
        - `request.time`

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.iam.Policy("main",
            name="tf_tests_policy_condition",
            no_principal=True,
            rules=[{
                "organization_id": "%s",
                "permission_set_names": ["AllProductsFullAccess"],
                "condition": "request.user_agent == 'My User Agent'",
            }])
        ```

        ## Import

        Policies can be imported using the `{id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:iam/policy:Policy main 11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param PolicyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(PolicyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 application_id: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 group_id: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 no_principal: Optional[pulumi.Input[_builtins.bool]] = None,
                 organization_id: Optional[pulumi.Input[_builtins.str]] = None,
                 rules: Optional[pulumi.Input[Sequence[pulumi.Input[Union['PolicyRuleArgs', 'PolicyRuleArgsDict']]]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 user_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = PolicyArgs.__new__(PolicyArgs)

            __props__.__dict__["application_id"] = application_id
            __props__.__dict__["description"] = description
            __props__.__dict__["group_id"] = group_id
            __props__.__dict__["name"] = name
            __props__.__dict__["no_principal"] = no_principal
            __props__.__dict__["organization_id"] = organization_id
            if rules is None and not opts.urn:
                raise TypeError("Missing required property 'rules'")
            __props__.__dict__["rules"] = rules
            __props__.__dict__["tags"] = tags
            __props__.__dict__["user_id"] = user_id
            __props__.__dict__["created_at"] = None
            __props__.__dict__["editable"] = None
            __props__.__dict__["updated_at"] = None
        alias_opts = pulumi.ResourceOptions(aliases=[pulumi.Alias(type_="scaleway:index/iamPolicy:IamPolicy")])
        opts = pulumi.ResourceOptions.merge(opts, alias_opts)
        super(Policy, __self__).__init__(
            'scaleway:iam/policy:Policy',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            application_id: Optional[pulumi.Input[_builtins.str]] = None,
            created_at: Optional[pulumi.Input[_builtins.str]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            editable: Optional[pulumi.Input[_builtins.bool]] = None,
            group_id: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            no_principal: Optional[pulumi.Input[_builtins.bool]] = None,
            organization_id: Optional[pulumi.Input[_builtins.str]] = None,
            rules: Optional[pulumi.Input[Sequence[pulumi.Input[Union['PolicyRuleArgs', 'PolicyRuleArgsDict']]]]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            updated_at: Optional[pulumi.Input[_builtins.str]] = None,
            user_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'Policy':
        """
        Get an existing Policy resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] application_id: ID of the application the policy will be linked to
        :param pulumi.Input[_builtins.str] created_at: The date and time of the creation of the policy.
        :param pulumi.Input[_builtins.str] description: The description of the IAM policy.
        :param pulumi.Input[_builtins.bool] editable: Whether the policy is editable.
        :param pulumi.Input[_builtins.str] group_id: ID of the group the policy will be linked to
        :param pulumi.Input[_builtins.str] name: The name of the IAM policy.
        :param pulumi.Input[_builtins.bool] no_principal: If the policy doesn't apply to a principal.
               
               > **Important** Only one of `user_id`, `group_id`, `application_id` and `no_principal` may be set.
        :param pulumi.Input[_builtins.str] organization_id: `organization_id`) The ID of the organization the policy is associated with.
        :param pulumi.Input[Sequence[pulumi.Input[Union['PolicyRuleArgs', 'PolicyRuleArgsDict']]]] rules: List of rules in the policy.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: The tags associated with the IAM policy.
        :param pulumi.Input[_builtins.str] updated_at: The date and time of the last update of the policy.
        :param pulumi.Input[_builtins.str] user_id: ID of the user the policy will be linked to
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _PolicyState.__new__(_PolicyState)

        __props__.__dict__["application_id"] = application_id
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["description"] = description
        __props__.__dict__["editable"] = editable
        __props__.__dict__["group_id"] = group_id
        __props__.__dict__["name"] = name
        __props__.__dict__["no_principal"] = no_principal
        __props__.__dict__["organization_id"] = organization_id
        __props__.__dict__["rules"] = rules
        __props__.__dict__["tags"] = tags
        __props__.__dict__["updated_at"] = updated_at
        __props__.__dict__["user_id"] = user_id
        return Policy(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="applicationId")
    def application_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        ID of the application the policy will be linked to
        """
        return pulumi.get(self, "application_id")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[_builtins.str]:
        """
        The date and time of the creation of the policy.
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The description of the IAM policy.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def editable(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether the policy is editable.
        """
        return pulumi.get(self, "editable")

    @_builtins.property
    @pulumi.getter(name="groupId")
    def group_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        ID of the group the policy will be linked to
        """
        return pulumi.get(self, "group_id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the IAM policy.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="noPrincipal")
    def no_principal(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        If the policy doesn't apply to a principal.

        > **Important** Only one of `user_id`, `group_id`, `application_id` and `no_principal` may be set.
        """
        return pulumi.get(self, "no_principal")

    @_builtins.property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> pulumi.Output[_builtins.str]:
        """
        `organization_id`) The ID of the organization the policy is associated with.
        """
        return pulumi.get(self, "organization_id")

    @_builtins.property
    @pulumi.getter
    def rules(self) -> pulumi.Output[Sequence['outputs.PolicyRule']]:
        """
        List of rules in the policy.
        """
        return pulumi.get(self, "rules")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        The tags associated with the IAM policy.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[_builtins.str]:
        """
        The date and time of the last update of the policy.
        """
        return pulumi.get(self, "updated_at")

    @_builtins.property
    @pulumi.getter(name="userId")
    def user_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        ID of the user the policy will be linked to
        """
        return pulumi.get(self, "user_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
from .. import _utilities
import typing
# Export this package's modules as members:
from .get_image import *
from .get_ip import *
from .get_placement_group import *
from .get_private_nic import *
from .get_security_group import *
from .get_server import *
from .get_server_type import *
from .get_servers import *
from .get_snapshot import *
from .get_volume import *
from .image import *
from .ip import *
from .ip_reverse_dns import *
from .placement_group import *
from .private_nic import *
from .security_group import *
from .security_group_rules import *
from .server import *
from .snapshot import *
from .user_data import *
from .volume import *
from ._inputs import *
from . import outputs



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetOfferResult',
    'AwaitableGetOfferResult',
    'get_offer',
    'get_offer_output',
]

@pulumi.output_type
class GetOfferResult:
    """
    A collection of values returned by getOffer.
    """
    def __init__(__self__, billing_operation_path=None, control_panel=None, id=None, name=None, offer_id=None, offers=None, price=None, products=None, region=None):
        if billing_operation_path and not isinstance(billing_operation_path, str):
            raise TypeError("Expected argument 'billing_operation_path' to be a str")
        pulumi.set(__self__, "billing_operation_path", billing_operation_path)
        if control_panel and not isinstance(control_panel, str):
            raise TypeError("Expected argument 'control_panel' to be a str")
        pulumi.set(__self__, "control_panel", control_panel)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if offer_id and not isinstance(offer_id, str):
            raise TypeError("Expected argument 'offer_id' to be a str")
        pulumi.set(__self__, "offer_id", offer_id)
        if offers and not isinstance(offers, list):
            raise TypeError("Expected argument 'offers' to be a list")
        pulumi.set(__self__, "offers", offers)
        if price and not isinstance(price, str):
            raise TypeError("Expected argument 'price' to be a str")
        pulumi.set(__self__, "price", price)
        if products and not isinstance(products, list):
            raise TypeError("Expected argument 'products' to be a list")
        pulumi.set(__self__, "products", products)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)

    @_builtins.property
    @pulumi.getter(name="billingOperationPath")
    def billing_operation_path(self) -> _builtins.str:
        """
        The billing operation identifier for the option.
        """
        return pulumi.get(self, "billing_operation_path")

    @_builtins.property
    @pulumi.getter(name="controlPanel")
    def control_panel(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "control_panel")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        The name of the option.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="offerId")
    def offer_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "offer_id")

    @_builtins.property
    @pulumi.getter
    def offers(self) -> Sequence['outputs.GetOfferOfferResult']:
        """
        The detailed offer of the hosting.
        """
        return pulumi.get(self, "offers")

    @_builtins.property
    @pulumi.getter
    def price(self) -> _builtins.str:
        """
        The offer price.
        """
        return pulumi.get(self, "price")

    @_builtins.property
    @pulumi.getter
    @_utilities.deprecated("""The product field is deprecated. Please use the offer field instead.""")
    def products(self) -> Sequence['outputs.GetOfferProductResult']:
        """
        (deprecated) The offer product.
        """
        return pulumi.get(self, "products")

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "region")


class AwaitableGetOfferResult(GetOfferResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetOfferResult(
            billing_operation_path=self.billing_operation_path,
            control_panel=self.control_panel,
            id=self.id,
            name=self.name,
            offer_id=self.offer_id,
            offers=self.offers,
            price=self.price,
            products=self.products,
            region=self.region)


def get_offer(control_panel: Optional[_builtins.str] = None,
              name: Optional[_builtins.str] = None,
              offer_id: Optional[_builtins.str] = None,
              region: Optional[_builtins.str] = None,
              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetOfferResult:
    """
    Gets information about a webhosting offer.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Get info by offer name
    by_name = scaleway.hosting.get_offer(name="performance",
        control_panel="Cpanel")
    # Get info by offer id
    by_id = scaleway.hosting.get_offer(offer_id="de2426b4-a9e9-11ec-b909-0242ac120002")
    ```


    :param _builtins.str control_panel: Name of the control panel (Cpanel or Plesk). This argument is only used when `offer_id` is not specified.
    :param _builtins.str name: The offer name. Only one of `name` and `offer_id` should be specified.
    :param _builtins.str offer_id: The offer id. Only one of `name` and `offer_id` should be specified.
    :param _builtins.str region: `region`) The region in which offer exists.
    """
    __args__ = dict()
    __args__['controlPanel'] = control_panel
    __args__['name'] = name
    __args__['offerId'] = offer_id
    __args__['region'] = region
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('scaleway:hosting/getOffer:getOffer', __args__, opts=opts, typ=GetOfferResult).value

    return AwaitableGetOfferResult(
        billing_operation_path=pulumi.get(__ret__, 'billing_operation_path'),
        control_panel=pulumi.get(__ret__, 'control_panel'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        offer_id=pulumi.get(__ret__, 'offer_id'),
        offers=pulumi.get(__ret__, 'offers'),
        price=pulumi.get(__ret__, 'price'),
        products=pulumi.get(__ret__, 'products'),
        region=pulumi.get(__ret__, 'region'))
def get_offer_output(control_panel: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                     name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                     offer_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                     region: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                     opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetOfferResult]:
    """
    Gets information about a webhosting offer.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Get info by offer name
    by_name = scaleway.hosting.get_offer(name="performance",
        control_panel="Cpanel")
    # Get info by offer id
    by_id = scaleway.hosting.get_offer(offer_id="de2426b4-a9e9-11ec-b909-0242ac120002")
    ```


    :param _builtins.str control_panel: Name of the control panel (Cpanel or Plesk). This argument is only used when `offer_id` is not specified.
    :param _builtins.str name: The offer name. Only one of `name` and `offer_id` should be specified.
    :param _builtins.str offer_id: The offer id. Only one of `name` and `offer_id` should be specified.
    :param _builtins.str region: `region`) The region in which offer exists.
    """
    __args__ = dict()
    __args__['controlPanel'] = control_panel
    __args__['name'] = name
    __args__['offerId'] = offer_id
    __args__['region'] = region
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('scaleway:hosting/getOffer:getOffer', __args__, opts=opts, typ=GetOfferResult)
    return __ret__.apply(lambda __response__: GetOfferResult(
        billing_operation_path=pulumi.get(__response__, 'billing_operation_path'),
        control_panel=pulumi.get(__response__, 'control_panel'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        offer_id=pulumi.get(__response__, 'offer_id'),
        offers=pulumi.get(__response__, 'offers'),
        price=pulumi.get(__response__, 'price'),
        products=pulumi.get(__response__, 'products'),
        region=pulumi.get(__response__, 'region')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetInstanceVolumeResult',
    'AwaitableGetInstanceVolumeResult',
    'get_instance_volume',
    'get_instance_volume_output',
]

warnings.warn("""scaleway.index/getinstancevolume.getInstanceVolume has been deprecated in favor of scaleway.instance/getvolume.getVolume""", DeprecationWarning)

@pulumi.output_type
class GetInstanceVolumeResult:
    """
    A collection of values returned by getInstanceVolume.
    """
    def __init__(__self__, from_snapshot_id=None, id=None, migrate_to_sbs=None, name=None, organization_id=None, project_id=None, server_id=None, size_in_gb=None, tags=None, type=None, volume_id=None, zone=None):
        if from_snapshot_id and not isinstance(from_snapshot_id, str):
            raise TypeError("Expected argument 'from_snapshot_id' to be a str")
        pulumi.set(__self__, "from_snapshot_id", from_snapshot_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if migrate_to_sbs and not isinstance(migrate_to_sbs, bool):
            raise TypeError("Expected argument 'migrate_to_sbs' to be a bool")
        pulumi.set(__self__, "migrate_to_sbs", migrate_to_sbs)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if organization_id and not isinstance(organization_id, str):
            raise TypeError("Expected argument 'organization_id' to be a str")
        pulumi.set(__self__, "organization_id", organization_id)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if server_id and not isinstance(server_id, str):
            raise TypeError("Expected argument 'server_id' to be a str")
        pulumi.set(__self__, "server_id", server_id)
        if size_in_gb and not isinstance(size_in_gb, int):
            raise TypeError("Expected argument 'size_in_gb' to be a int")
        pulumi.set(__self__, "size_in_gb", size_in_gb)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)
        if volume_id and not isinstance(volume_id, str):
            raise TypeError("Expected argument 'volume_id' to be a str")
        pulumi.set(__self__, "volume_id", volume_id)
        if zone and not isinstance(zone, str):
            raise TypeError("Expected argument 'zone' to be a str")
        pulumi.set(__self__, "zone", zone)

    @_builtins.property
    @pulumi.getter(name="fromSnapshotId")
    def from_snapshot_id(self) -> _builtins.str:
        return pulumi.get(self, "from_snapshot_id")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="migrateToSbs")
    def migrate_to_sbs(self) -> _builtins.bool:
        return pulumi.get(self, "migrate_to_sbs")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> _builtins.str:
        """
        The ID of the organization the volume is associated with.
        """
        return pulumi.get(self, "organization_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="serverId")
    def server_id(self) -> _builtins.str:
        return pulumi.get(self, "server_id")

    @_builtins.property
    @pulumi.getter(name="sizeInGb")
    def size_in_gb(self) -> _builtins.int:
        return pulumi.get(self, "size_in_gb")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Sequence[_builtins.str]:
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter
    def type(self) -> _builtins.str:
        return pulumi.get(self, "type")

    @_builtins.property
    @pulumi.getter(name="volumeId")
    def volume_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "volume_id")

    @_builtins.property
    @pulumi.getter
    def zone(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "zone")


class AwaitableGetInstanceVolumeResult(GetInstanceVolumeResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetInstanceVolumeResult(
            from_snapshot_id=self.from_snapshot_id,
            id=self.id,
            migrate_to_sbs=self.migrate_to_sbs,
            name=self.name,
            organization_id=self.organization_id,
            project_id=self.project_id,
            server_id=self.server_id,
            size_in_gb=self.size_in_gb,
            tags=self.tags,
            type=self.type,
            volume_id=self.volume_id,
            zone=self.zone)


def get_instance_volume(name: Optional[_builtins.str] = None,
                        project_id: Optional[_builtins.str] = None,
                        volume_id: Optional[_builtins.str] = None,
                        zone: Optional[_builtins.str] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetInstanceVolumeResult:
    """
    Gets information about an instance volume.


    :param _builtins.str name: The volume name.
           Only one of `name` and `volume_id` should be specified.
    :param _builtins.str project_id: The ID of the project the volume is associated with.
    :param _builtins.str volume_id: The volume id.
           Only one of `name` and `volume_id` should be specified.
    :param _builtins.str zone: `zone`) The zone in which the volume exists.
    """
    pulumi.log.warn("""get_instance_volume is deprecated: scaleway.index/getinstancevolume.getInstanceVolume has been deprecated in favor of scaleway.instance/getvolume.getVolume""")
    __args__ = dict()
    __args__['name'] = name
    __args__['projectId'] = project_id
    __args__['volumeId'] = volume_id
    __args__['zone'] = zone
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('scaleway:index/getInstanceVolume:getInstanceVolume', __args__, opts=opts, typ=GetInstanceVolumeResult).value

    return AwaitableGetInstanceVolumeResult(
        from_snapshot_id=pulumi.get(__ret__, 'from_snapshot_id'),
        id=pulumi.get(__ret__, 'id'),
        migrate_to_sbs=pulumi.get(__ret__, 'migrate_to_sbs'),
        name=pulumi.get(__ret__, 'name'),
        organization_id=pulumi.get(__ret__, 'organization_id'),
        project_id=pulumi.get(__ret__, 'project_id'),
        server_id=pulumi.get(__ret__, 'server_id'),
        size_in_gb=pulumi.get(__ret__, 'size_in_gb'),
        tags=pulumi.get(__ret__, 'tags'),
        type=pulumi.get(__ret__, 'type'),
        volume_id=pulumi.get(__ret__, 'volume_id'),
        zone=pulumi.get(__ret__, 'zone'))
def get_instance_volume_output(name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                               project_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                               volume_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                               zone: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                               opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetInstanceVolumeResult]:
    """
    Gets information about an instance volume.


    :param _builtins.str name: The volume name.
           Only one of `name` and `volume_id` should be specified.
    :param _builtins.str project_id: The ID of the project the volume is associated with.
    :param _builtins.str volume_id: The volume id.
           Only one of `name` and `volume_id` should be specified.
    :param _builtins.str zone: `zone`) The zone in which the volume exists.
    """
    pulumi.log.warn("""get_instance_volume is deprecated: scaleway.index/getinstancevolume.getInstanceVolume has been deprecated in favor of scaleway.instance/getvolume.getVolume""")
    __args__ = dict()
    __args__['name'] = name
    __args__['projectId'] = project_id
    __args__['volumeId'] = volume_id
    __args__['zone'] = zone
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('scaleway:index/getInstanceVolume:getInstanceVolume', __args__, opts=opts, typ=GetInstanceVolumeResult)
    return __ret__.apply(lambda __response__: GetInstanceVolumeResult(
        from_snapshot_id=pulumi.get(__response__, 'from_snapshot_id'),
        id=pulumi.get(__response__, 'id'),
        migrate_to_sbs=pulumi.get(__response__, 'migrate_to_sbs'),
        name=pulumi.get(__response__, 'name'),
        organization_id=pulumi.get(__response__, 'organization_id'),
        project_id=pulumi.get(__response__, 'project_id'),
        server_id=pulumi.get(__response__, 'server_id'),
        size_in_gb=pulumi.get(__response__, 'size_in_gb'),
        tags=pulumi.get(__response__, 'tags'),
        type=pulumi.get(__response__, 'type'),
        volume_id=pulumi.get(__response__, 'volume_id'),
        zone=pulumi.get(__response__, 'zone')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ReadReplicaArgs', 'ReadReplica']

@pulumi.input_type
class ReadReplicaArgs:
    def __init__(__self__, *,
                 instance_id: pulumi.Input[_builtins.str],
                 direct_access: Optional[pulumi.Input['ReadReplicaDirectAccessArgs']] = None,
                 private_network: Optional[pulumi.Input['ReadReplicaPrivateNetworkArgs']] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 same_zone: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        The set of arguments for constructing a ReadReplica resource.
        :param pulumi.Input[_builtins.str] instance_id: UUID of the rdb instance.
               
               > **Important:** The replica musts contains at least one `direct_access` or `private_network`. It can contain both.
        :param pulumi.Input['ReadReplicaDirectAccessArgs'] direct_access: Creates a direct access endpoint to rdb replica.
        :param pulumi.Input['ReadReplicaPrivateNetworkArgs'] private_network: Create an endpoint in a Private Netork.
        :param pulumi.Input[_builtins.str] region: `region`) The region
               in which the Read Replica should be created.
        :param pulumi.Input[_builtins.bool] same_zone: Defines whether to create the replica in the same availability zone as the main instance nodes or not.
        """
        pulumi.set(__self__, "instance_id", instance_id)
        if direct_access is not None:
            pulumi.set(__self__, "direct_access", direct_access)
        if private_network is not None:
            pulumi.set(__self__, "private_network", private_network)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if same_zone is not None:
            pulumi.set(__self__, "same_zone", same_zone)

    @_builtins.property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Input[_builtins.str]:
        """
        UUID of the rdb instance.

        > **Important:** The replica musts contains at least one `direct_access` or `private_network`. It can contain both.
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "instance_id", value)

    @_builtins.property
    @pulumi.getter(name="directAccess")
    def direct_access(self) -> Optional[pulumi.Input['ReadReplicaDirectAccessArgs']]:
        """
        Creates a direct access endpoint to rdb replica.
        """
        return pulumi.get(self, "direct_access")

    @direct_access.setter
    def direct_access(self, value: Optional[pulumi.Input['ReadReplicaDirectAccessArgs']]):
        pulumi.set(self, "direct_access", value)

    @_builtins.property
    @pulumi.getter(name="privateNetwork")
    def private_network(self) -> Optional[pulumi.Input['ReadReplicaPrivateNetworkArgs']]:
        """
        Create an endpoint in a Private Netork.
        """
        return pulumi.get(self, "private_network")

    @private_network.setter
    def private_network(self, value: Optional[pulumi.Input['ReadReplicaPrivateNetworkArgs']]):
        pulumi.set(self, "private_network", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `region`) The region
        in which the Read Replica should be created.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="sameZone")
    def same_zone(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Defines whether to create the replica in the same availability zone as the main instance nodes or not.
        """
        return pulumi.get(self, "same_zone")

    @same_zone.setter
    def same_zone(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "same_zone", value)


@pulumi.input_type
class _ReadReplicaState:
    def __init__(__self__, *,
                 direct_access: Optional[pulumi.Input['ReadReplicaDirectAccessArgs']] = None,
                 instance_id: Optional[pulumi.Input[_builtins.str]] = None,
                 private_network: Optional[pulumi.Input['ReadReplicaPrivateNetworkArgs']] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 same_zone: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        Input properties used for looking up and filtering ReadReplica resources.
        :param pulumi.Input['ReadReplicaDirectAccessArgs'] direct_access: Creates a direct access endpoint to rdb replica.
        :param pulumi.Input[_builtins.str] instance_id: UUID of the rdb instance.
               
               > **Important:** The replica musts contains at least one `direct_access` or `private_network`. It can contain both.
        :param pulumi.Input['ReadReplicaPrivateNetworkArgs'] private_network: Create an endpoint in a Private Netork.
        :param pulumi.Input[_builtins.str] region: `region`) The region
               in which the Read Replica should be created.
        :param pulumi.Input[_builtins.bool] same_zone: Defines whether to create the replica in the same availability zone as the main instance nodes or not.
        """
        if direct_access is not None:
            pulumi.set(__self__, "direct_access", direct_access)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if private_network is not None:
            pulumi.set(__self__, "private_network", private_network)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if same_zone is not None:
            pulumi.set(__self__, "same_zone", same_zone)

    @_builtins.property
    @pulumi.getter(name="directAccess")
    def direct_access(self) -> Optional[pulumi.Input['ReadReplicaDirectAccessArgs']]:
        """
        Creates a direct access endpoint to rdb replica.
        """
        return pulumi.get(self, "direct_access")

    @direct_access.setter
    def direct_access(self, value: Optional[pulumi.Input['ReadReplicaDirectAccessArgs']]):
        pulumi.set(self, "direct_access", value)

    @_builtins.property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        UUID of the rdb instance.

        > **Important:** The replica musts contains at least one `direct_access` or `private_network`. It can contain both.
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "instance_id", value)

    @_builtins.property
    @pulumi.getter(name="privateNetwork")
    def private_network(self) -> Optional[pulumi.Input['ReadReplicaPrivateNetworkArgs']]:
        """
        Create an endpoint in a Private Netork.
        """
        return pulumi.get(self, "private_network")

    @private_network.setter
    def private_network(self, value: Optional[pulumi.Input['ReadReplicaPrivateNetworkArgs']]):
        pulumi.set(self, "private_network", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `region`) The region
        in which the Read Replica should be created.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="sameZone")
    def same_zone(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Defines whether to create the replica in the same availability zone as the main instance nodes or not.
        """
        return pulumi.get(self, "same_zone")

    @same_zone.setter
    def same_zone(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "same_zone", value)


@pulumi.type_token("scaleway:databases/readReplica:ReadReplica")
class ReadReplica(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 direct_access: Optional[pulumi.Input[Union['ReadReplicaDirectAccessArgs', 'ReadReplicaDirectAccessArgsDict']]] = None,
                 instance_id: Optional[pulumi.Input[_builtins.str]] = None,
                 private_network: Optional[pulumi.Input[Union['ReadReplicaPrivateNetworkArgs', 'ReadReplicaPrivateNetworkArgsDict']]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 same_zone: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        """
        Creates and manages Read Replicas.
        For more information refer to the [API documentation](https://www.scaleway.com/en/developers/api/managed-database-postgre-mysql/).

        ## Example Usage

        ### Basic

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        instance = scaleway.databases.Instance("instance",
            name="test-rdb-rr-update",
            node_type="db-dev-s",
            engine="PostgreSQL-14",
            is_ha_cluster=False,
            disable_backup=True,
            user_name="my_initial_user",
            password="thiZ_is_v&ry_s3cret",
            tags=[
                "terraform-test",
                "scaleway_rdb_read_replica",
                "minimal",
            ])
        replica = scaleway.databases.ReadReplica("replica",
            instance_id=instance.id,
            direct_access={})
        ```

        ### Private network with static endpoint

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        instance = scaleway.databases.Instance("instance",
            name="rdb_instance",
            node_type="db-dev-s",
            engine="PostgreSQL-14",
            is_ha_cluster=False,
            disable_backup=True,
            user_name="my_initial_user",
            password="thiZ_is_v&ry_s3cret")
        pn = scaleway.network.PrivateNetwork("pn")
        replica = scaleway.databases.ReadReplica("replica",
            instance_id=instance.id,
            private_network={
                "private_network_id": pn.id,
                "service_ip": "192.168.1.254/24",
            })
        ```

        ### Private network with IPAM

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        instance = scaleway.databases.Instance("instance",
            name="rdb_instance",
            node_type="db-dev-s",
            engine="PostgreSQL-14",
            is_ha_cluster=False,
            disable_backup=True,
            user_name="my_initial_user",
            password="thiZ_is_v&ry_s3cret")
        pn = scaleway.network.PrivateNetwork("pn")
        replica = scaleway.databases.ReadReplica("replica",
            instance_id=instance.id,
            private_network={
                "private_network_id": pn.id,
                "enable_ipam": True,
            })
        ```

        ## Import

        Read Replicas can be imported using the `{region}/{id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:databases/readReplica:ReadReplica rr fr-par/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['ReadReplicaDirectAccessArgs', 'ReadReplicaDirectAccessArgsDict']] direct_access: Creates a direct access endpoint to rdb replica.
        :param pulumi.Input[_builtins.str] instance_id: UUID of the rdb instance.
               
               > **Important:** The replica musts contains at least one `direct_access` or `private_network`. It can contain both.
        :param pulumi.Input[Union['ReadReplicaPrivateNetworkArgs', 'ReadReplicaPrivateNetworkArgsDict']] private_network: Create an endpoint in a Private Netork.
        :param pulumi.Input[_builtins.str] region: `region`) The region
               in which the Read Replica should be created.
        :param pulumi.Input[_builtins.bool] same_zone: Defines whether to create the replica in the same availability zone as the main instance nodes or not.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ReadReplicaArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates and manages Read Replicas.
        For more information refer to the [API documentation](https://www.scaleway.com/en/developers/api/managed-database-postgre-mysql/).

        ## Example Usage

        ### Basic

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        instance = scaleway.databases.Instance("instance",
            name="test-rdb-rr-update",
            node_type="db-dev-s",
            engine="PostgreSQL-14",
            is_ha_cluster=False,
            disable_backup=True,
            user_name="my_initial_user",
            password="thiZ_is_v&ry_s3cret",
            tags=[
                "terraform-test",
                "scaleway_rdb_read_replica",
                "minimal",
            ])
        replica = scaleway.databases.ReadReplica("replica",
            instance_id=instance.id,
            direct_access={})
        ```

        ### Private network with static endpoint

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        instance = scaleway.databases.Instance("instance",
            name="rdb_instance",
            node_type="db-dev-s",
            engine="PostgreSQL-14",
            is_ha_cluster=False,
            disable_backup=True,
            user_name="my_initial_user",
            password="thiZ_is_v&ry_s3cret")
        pn = scaleway.network.PrivateNetwork("pn")
        replica = scaleway.databases.ReadReplica("replica",
            instance_id=instance.id,
            private_network={
                "private_network_id": pn.id,
                "service_ip": "192.168.1.254/24",
            })
        ```

        ### Private network with IPAM

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        instance = scaleway.databases.Instance("instance",
            name="rdb_instance",
            node_type="db-dev-s",
            engine="PostgreSQL-14",
            is_ha_cluster=False,
            disable_backup=True,
            user_name="my_initial_user",
            password="thiZ_is_v&ry_s3cret")
        pn = scaleway.network.PrivateNetwork("pn")
        replica = scaleway.databases.ReadReplica("replica",
            instance_id=instance.id,
            private_network={
                "private_network_id": pn.id,
                "enable_ipam": True,
            })
        ```

        ## Import

        Read Replicas can be imported using the `{region}/{id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:databases/readReplica:ReadReplica rr fr-par/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param ReadReplicaArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ReadReplicaArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 direct_access: Optional[pulumi.Input[Union['ReadReplicaDirectAccessArgs', 'ReadReplicaDirectAccessArgsDict']]] = None,
                 instance_id: Optional[pulumi.Input[_builtins.str]] = None,
                 private_network: Optional[pulumi.Input[Union['ReadReplicaPrivateNetworkArgs', 'ReadReplicaPrivateNetworkArgsDict']]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 same_zone: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ReadReplicaArgs.__new__(ReadReplicaArgs)

            __props__.__dict__["direct_access"] = direct_access
            if instance_id is None and not opts.urn:
                raise TypeError("Missing required property 'instance_id'")
            __props__.__dict__["instance_id"] = instance_id
            __props__.__dict__["private_network"] = private_network
            __props__.__dict__["region"] = region
            __props__.__dict__["same_zone"] = same_zone
        alias_opts = pulumi.ResourceOptions(aliases=[pulumi.Alias(type_="scaleway:index/databaseReadReplica:DatabaseReadReplica")])
        opts = pulumi.ResourceOptions.merge(opts, alias_opts)
        super(ReadReplica, __self__).__init__(
            'scaleway:databases/readReplica:ReadReplica',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            direct_access: Optional[pulumi.Input[Union['ReadReplicaDirectAccessArgs', 'ReadReplicaDirectAccessArgsDict']]] = None,
            instance_id: Optional[pulumi.Input[_builtins.str]] = None,
            private_network: Optional[pulumi.Input[Union['ReadReplicaPrivateNetworkArgs', 'ReadReplicaPrivateNetworkArgsDict']]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None,
            same_zone: Optional[pulumi.Input[_builtins.bool]] = None) -> 'ReadReplica':
        """
        Get an existing ReadReplica resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['ReadReplicaDirectAccessArgs', 'ReadReplicaDirectAccessArgsDict']] direct_access: Creates a direct access endpoint to rdb replica.
        :param pulumi.Input[_builtins.str] instance_id: UUID of the rdb instance.
               
               > **Important:** The replica musts contains at least one `direct_access` or `private_network`. It can contain both.
        :param pulumi.Input[Union['ReadReplicaPrivateNetworkArgs', 'ReadReplicaPrivateNetworkArgsDict']] private_network: Create an endpoint in a Private Netork.
        :param pulumi.Input[_builtins.str] region: `region`) The region
               in which the Read Replica should be created.
        :param pulumi.Input[_builtins.bool] same_zone: Defines whether to create the replica in the same availability zone as the main instance nodes or not.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ReadReplicaState.__new__(_ReadReplicaState)

        __props__.__dict__["direct_access"] = direct_access
        __props__.__dict__["instance_id"] = instance_id
        __props__.__dict__["private_network"] = private_network
        __props__.__dict__["region"] = region
        __props__.__dict__["same_zone"] = same_zone
        return ReadReplica(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="directAccess")
    def direct_access(self) -> pulumi.Output[Optional['outputs.ReadReplicaDirectAccess']]:
        """
        Creates a direct access endpoint to rdb replica.
        """
        return pulumi.get(self, "direct_access")

    @_builtins.property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[_builtins.str]:
        """
        UUID of the rdb instance.

        > **Important:** The replica musts contains at least one `direct_access` or `private_network`. It can contain both.
        """
        return pulumi.get(self, "instance_id")

    @_builtins.property
    @pulumi.getter(name="privateNetwork")
    def private_network(self) -> pulumi.Output[Optional['outputs.ReadReplicaPrivateNetwork']]:
        """
        Create an endpoint in a Private Netork.
        """
        return pulumi.get(self, "private_network")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        `region`) The region
        in which the Read Replica should be created.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter(name="sameZone")
    def same_zone(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Defines whether to create the replica in the same availability zone as the main instance nodes or not.
        """
        return pulumi.get(self, "same_zone")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetSqsResult',
    'AwaitableGetSqsResult',
    'get_sqs',
    'get_sqs_output',
]

@pulumi.output_type
class GetSqsResult:
    """
    A collection of values returned by getSqs.
    """
    def __init__(__self__, endpoint=None, id=None, project_id=None, region=None):
        if endpoint and not isinstance(endpoint, str):
            raise TypeError("Expected argument 'endpoint' to be a str")
        pulumi.set(__self__, "endpoint", endpoint)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)

    @_builtins.property
    @pulumi.getter
    def endpoint(self) -> _builtins.str:
        """
        The endpoint of the SQS service for this Project.
        """
        return pulumi.get(self, "endpoint")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "region")


class AwaitableGetSqsResult(GetSqsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSqsResult(
            endpoint=self.endpoint,
            id=self.id,
            project_id=self.project_id,
            region=self.region)


def get_sqs(project_id: Optional[_builtins.str] = None,
            region: Optional[_builtins.str] = None,
            opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSqsResult:
    """
    Gets information about SQS for a Project

    ## Examples

    ### Basic

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # For default project
    main = scaleway.mnq.get_sqs()
    # For specific project
    for_project = scaleway.mnq.get_sqs(project_id=main_scaleway_account_project["id"])
    ```


    :param _builtins.str project_id: `project_id`) The ID of the Project in which SQS is enabled.
    :param _builtins.str region: `region`). The region in which SQS is enabled.
    """
    __args__ = dict()
    __args__['projectId'] = project_id
    __args__['region'] = region
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('scaleway:mnq/getSqs:getSqs', __args__, opts=opts, typ=GetSqsResult).value

    return AwaitableGetSqsResult(
        endpoint=pulumi.get(__ret__, 'endpoint'),
        id=pulumi.get(__ret__, 'id'),
        project_id=pulumi.get(__ret__, 'project_id'),
        region=pulumi.get(__ret__, 'region'))
def get_sqs_output(project_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                   region: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                   opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetSqsResult]:
    """
    Gets information about SQS for a Project

    ## Examples

    ### Basic

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # For default project
    main = scaleway.mnq.get_sqs()
    # For specific project
    for_project = scaleway.mnq.get_sqs(project_id=main_scaleway_account_project["id"])
    ```


    :param _builtins.str project_id: `project_id`) The ID of the Project in which SQS is enabled.
    :param _builtins.str region: `region`). The region in which SQS is enabled.
    """
    __args__ = dict()
    __args__['projectId'] = project_id
    __args__['region'] = region
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('scaleway:mnq/getSqs:getSqs', __args__, opts=opts, typ=GetSqsResult)
    return __ret__.apply(lambda __response__: GetSqsResult(
        endpoint=pulumi.get(__response__, 'endpoint'),
        id=pulumi.get(__response__, 'id'),
        project_id=pulumi.get(__response__, 'project_id'),
        region=pulumi.get(__response__, 'region')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['RouteArgs', 'Route']

@pulumi.input_type
class RouteArgs:
    def __init__(__self__, *,
                 hub_id: pulumi.Input[_builtins.str],
                 topic: pulumi.Input[_builtins.str],
                 database: Optional[pulumi.Input['RouteDatabaseArgs']] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 rest: Optional[pulumi.Input['RouteRestArgs']] = None,
                 s3: Optional[pulumi.Input['RouteS3Args']] = None):
        """
        The set of arguments for constructing a Route resource.
        :param pulumi.Input[_builtins.str] hub_id: The hub ID to which the Route will be attached to.
        :param pulumi.Input[_builtins.str] topic: The topic the Route subscribes to, wildcards allowed (e.g. `thelab/+/temperature/#`).
        :param pulumi.Input['RouteDatabaseArgs'] database: Configuration block for the database routes. See  [product documentation](https://www.scaleway.com/en/docs/iot-hub/how-to/create-route/) for a better understanding of the parameters.
        :param pulumi.Input[_builtins.str] name: The name of the IoT Route you want to create (e.g. `my-route`).
        :param pulumi.Input[_builtins.str] region: (Defaults to provider `region`) The region in which the Route is attached to.
        :param pulumi.Input['RouteRestArgs'] rest: Configuration block for the rest routes. See [product documentation](https://www.scaleway.com/en/docs/iot-hub/how-to/create-route/) for a better understanding of the parameters.
        :param pulumi.Input['RouteS3Args'] s3: Configuration block for the S3 routes. See [product documentation](https://www.scaleway.com/en/docs/iot-hub/how-to/create-route/) for a better understanding of the parameters.
        """
        pulumi.set(__self__, "hub_id", hub_id)
        pulumi.set(__self__, "topic", topic)
        if database is not None:
            pulumi.set(__self__, "database", database)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if rest is not None:
            pulumi.set(__self__, "rest", rest)
        if s3 is not None:
            pulumi.set(__self__, "s3", s3)

    @_builtins.property
    @pulumi.getter(name="hubId")
    def hub_id(self) -> pulumi.Input[_builtins.str]:
        """
        The hub ID to which the Route will be attached to.
        """
        return pulumi.get(self, "hub_id")

    @hub_id.setter
    def hub_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "hub_id", value)

    @_builtins.property
    @pulumi.getter
    def topic(self) -> pulumi.Input[_builtins.str]:
        """
        The topic the Route subscribes to, wildcards allowed (e.g. `thelab/+/temperature/#`).
        """
        return pulumi.get(self, "topic")

    @topic.setter
    def topic(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "topic", value)

    @_builtins.property
    @pulumi.getter
    def database(self) -> Optional[pulumi.Input['RouteDatabaseArgs']]:
        """
        Configuration block for the database routes. See  [product documentation](https://www.scaleway.com/en/docs/iot-hub/how-to/create-route/) for a better understanding of the parameters.
        """
        return pulumi.get(self, "database")

    @database.setter
    def database(self, value: Optional[pulumi.Input['RouteDatabaseArgs']]):
        pulumi.set(self, "database", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the IoT Route you want to create (e.g. `my-route`).
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (Defaults to provider `region`) The region in which the Route is attached to.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter
    def rest(self) -> Optional[pulumi.Input['RouteRestArgs']]:
        """
        Configuration block for the rest routes. See [product documentation](https://www.scaleway.com/en/docs/iot-hub/how-to/create-route/) for a better understanding of the parameters.
        """
        return pulumi.get(self, "rest")

    @rest.setter
    def rest(self, value: Optional[pulumi.Input['RouteRestArgs']]):
        pulumi.set(self, "rest", value)

    @_builtins.property
    @pulumi.getter
    def s3(self) -> Optional[pulumi.Input['RouteS3Args']]:
        """
        Configuration block for the S3 routes. See [product documentation](https://www.scaleway.com/en/docs/iot-hub/how-to/create-route/) for a better understanding of the parameters.
        """
        return pulumi.get(self, "s3")

    @s3.setter
    def s3(self, value: Optional[pulumi.Input['RouteS3Args']]):
        pulumi.set(self, "s3", value)


@pulumi.input_type
class _RouteState:
    def __init__(__self__, *,
                 created_at: Optional[pulumi.Input[_builtins.str]] = None,
                 database: Optional[pulumi.Input['RouteDatabaseArgs']] = None,
                 hub_id: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 rest: Optional[pulumi.Input['RouteRestArgs']] = None,
                 s3: Optional[pulumi.Input['RouteS3Args']] = None,
                 topic: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Route resources.
        :param pulumi.Input[_builtins.str] created_at: The date and time the Route was created.
        :param pulumi.Input['RouteDatabaseArgs'] database: Configuration block for the database routes. See  [product documentation](https://www.scaleway.com/en/docs/iot-hub/how-to/create-route/) for a better understanding of the parameters.
        :param pulumi.Input[_builtins.str] hub_id: The hub ID to which the Route will be attached to.
        :param pulumi.Input[_builtins.str] name: The name of the IoT Route you want to create (e.g. `my-route`).
        :param pulumi.Input[_builtins.str] region: (Defaults to provider `region`) The region in which the Route is attached to.
        :param pulumi.Input['RouteRestArgs'] rest: Configuration block for the rest routes. See [product documentation](https://www.scaleway.com/en/docs/iot-hub/how-to/create-route/) for a better understanding of the parameters.
        :param pulumi.Input['RouteS3Args'] s3: Configuration block for the S3 routes. See [product documentation](https://www.scaleway.com/en/docs/iot-hub/how-to/create-route/) for a better understanding of the parameters.
        :param pulumi.Input[_builtins.str] topic: The topic the Route subscribes to, wildcards allowed (e.g. `thelab/+/temperature/#`).
        """
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if database is not None:
            pulumi.set(__self__, "database", database)
        if hub_id is not None:
            pulumi.set(__self__, "hub_id", hub_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if rest is not None:
            pulumi.set(__self__, "rest", rest)
        if s3 is not None:
            pulumi.set(__self__, "s3", s3)
        if topic is not None:
            pulumi.set(__self__, "topic", topic)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date and time the Route was created.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created_at", value)

    @_builtins.property
    @pulumi.getter
    def database(self) -> Optional[pulumi.Input['RouteDatabaseArgs']]:
        """
        Configuration block for the database routes. See  [product documentation](https://www.scaleway.com/en/docs/iot-hub/how-to/create-route/) for a better understanding of the parameters.
        """
        return pulumi.get(self, "database")

    @database.setter
    def database(self, value: Optional[pulumi.Input['RouteDatabaseArgs']]):
        pulumi.set(self, "database", value)

    @_builtins.property
    @pulumi.getter(name="hubId")
    def hub_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The hub ID to which the Route will be attached to.
        """
        return pulumi.get(self, "hub_id")

    @hub_id.setter
    def hub_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "hub_id", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the IoT Route you want to create (e.g. `my-route`).
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (Defaults to provider `region`) The region in which the Route is attached to.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter
    def rest(self) -> Optional[pulumi.Input['RouteRestArgs']]:
        """
        Configuration block for the rest routes. See [product documentation](https://www.scaleway.com/en/docs/iot-hub/how-to/create-route/) for a better understanding of the parameters.
        """
        return pulumi.get(self, "rest")

    @rest.setter
    def rest(self, value: Optional[pulumi.Input['RouteRestArgs']]):
        pulumi.set(self, "rest", value)

    @_builtins.property
    @pulumi.getter
    def s3(self) -> Optional[pulumi.Input['RouteS3Args']]:
        """
        Configuration block for the S3 routes. See [product documentation](https://www.scaleway.com/en/docs/iot-hub/how-to/create-route/) for a better understanding of the parameters.
        """
        return pulumi.get(self, "s3")

    @s3.setter
    def s3(self, value: Optional[pulumi.Input['RouteS3Args']]):
        pulumi.set(self, "s3", value)

    @_builtins.property
    @pulumi.getter
    def topic(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The topic the Route subscribes to, wildcards allowed (e.g. `thelab/+/temperature/#`).
        """
        return pulumi.get(self, "topic")

    @topic.setter
    def topic(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "topic", value)


@pulumi.type_token("scaleway:iot/route:Route")
class Route(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 database: Optional[pulumi.Input[Union['RouteDatabaseArgs', 'RouteDatabaseArgsDict']]] = None,
                 hub_id: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 rest: Optional[pulumi.Input[Union['RouteRestArgs', 'RouteRestArgsDict']]] = None,
                 s3: Optional[pulumi.Input[Union['RouteS3Args', 'RouteS3ArgsDict']]] = None,
                 topic: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        ## Example Usage

        ### Database Route

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main_hub = scaleway.iot.Hub("main",
            name="main",
            product_plan="plan_shared")
        iot = scaleway.databases.Instance("iot",
            name="iot",
            node_type="db-dev-s",
            engine="PostgreSQL-12",
            user_name="root",
            password="T3stP4ssw0rdD0N0tUs3!")
        main = scaleway.iot.Route("main",
            name="default",
            hub_id=main_hub.id,
            topic="#",
            database={
                "query": \"\"\"INSERT INTO measurements(
        \\tpush_time,
        \\treport_time,
        \\tstation_id,
        \\ttemperature,
        \\thumidity
        ) VALUES (
        \\tNOW(),
        \\tTIMESTAMP 'epoch' + (($PAYLOAD::jsonb->'last_reported')::integer * INTERVAL '1 second'),
        \\t($PAYLOAD::jsonb->'station_id')::uuid,
        \\t($PAYLOAD::jsonb->'temperature')::decimal,
        \\t($PAYLOAD::jsonb->'humidity'):decimal:
        );
        \"\"\",
                "host": iot.endpoint_ip,
                "port": iot.endpoint_port,
                "dbname": "rdb",
                "username": iot.user_name,
                "password": iot.password,
            })
        ```

        ### S3 Route

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main_hub = scaleway.iot.Hub("main",
            name="main",
            product_plan="plan_shared")
        main_bucket = scaleway.object.Bucket("main",
            region="fr-par",
            name="my_awesome-bucket")
        main = scaleway.iot.Route("main",
            name="main",
            hub_id=main_hub.id,
            topic="#",
            s3={
                "bucket_region": main_bucket.region,
                "bucket_name": main_bucket.name,
                "object_prefix": "foo",
                "strategy": "per_topic",
            })
        ```

        ### Rest Route

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main_hub = scaleway.iot.Hub("main",
            name="main",
            product_plan="plan_shared")
        main = scaleway.iot.Route("main",
            name="main",
            hub_id=main_hub.id,
            topic="#",
            rest={
                "verb": "get",
                "uri": "http://scaleway.com",
                "headers": {
                    "X-awesome-header": "my-awesome-value",
                },
            })
        ```

        ## Import

        IoT Routes can be imported using the `{region}/{id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:iot/route:Route route01 fr-par/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['RouteDatabaseArgs', 'RouteDatabaseArgsDict']] database: Configuration block for the database routes. See  [product documentation](https://www.scaleway.com/en/docs/iot-hub/how-to/create-route/) for a better understanding of the parameters.
        :param pulumi.Input[_builtins.str] hub_id: The hub ID to which the Route will be attached to.
        :param pulumi.Input[_builtins.str] name: The name of the IoT Route you want to create (e.g. `my-route`).
        :param pulumi.Input[_builtins.str] region: (Defaults to provider `region`) The region in which the Route is attached to.
        :param pulumi.Input[Union['RouteRestArgs', 'RouteRestArgsDict']] rest: Configuration block for the rest routes. See [product documentation](https://www.scaleway.com/en/docs/iot-hub/how-to/create-route/) for a better understanding of the parameters.
        :param pulumi.Input[Union['RouteS3Args', 'RouteS3ArgsDict']] s3: Configuration block for the S3 routes. See [product documentation](https://www.scaleway.com/en/docs/iot-hub/how-to/create-route/) for a better understanding of the parameters.
        :param pulumi.Input[_builtins.str] topic: The topic the Route subscribes to, wildcards allowed (e.g. `thelab/+/temperature/#`).
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RouteArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ### Database Route

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main_hub = scaleway.iot.Hub("main",
            name="main",
            product_plan="plan_shared")
        iot = scaleway.databases.Instance("iot",
            name="iot",
            node_type="db-dev-s",
            engine="PostgreSQL-12",
            user_name="root",
            password="T3stP4ssw0rdD0N0tUs3!")
        main = scaleway.iot.Route("main",
            name="default",
            hub_id=main_hub.id,
            topic="#",
            database={
                "query": \"\"\"INSERT INTO measurements(
        \\tpush_time,
        \\treport_time,
        \\tstation_id,
        \\ttemperature,
        \\thumidity
        ) VALUES (
        \\tNOW(),
        \\tTIMESTAMP 'epoch' + (($PAYLOAD::jsonb->'last_reported')::integer * INTERVAL '1 second'),
        \\t($PAYLOAD::jsonb->'station_id')::uuid,
        \\t($PAYLOAD::jsonb->'temperature')::decimal,
        \\t($PAYLOAD::jsonb->'humidity'):decimal:
        );
        \"\"\",
                "host": iot.endpoint_ip,
                "port": iot.endpoint_port,
                "dbname": "rdb",
                "username": iot.user_name,
                "password": iot.password,
            })
        ```

        ### S3 Route

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main_hub = scaleway.iot.Hub("main",
            name="main",
            product_plan="plan_shared")
        main_bucket = scaleway.object.Bucket("main",
            region="fr-par",
            name="my_awesome-bucket")
        main = scaleway.iot.Route("main",
            name="main",
            hub_id=main_hub.id,
            topic="#",
            s3={
                "bucket_region": main_bucket.region,
                "bucket_name": main_bucket.name,
                "object_prefix": "foo",
                "strategy": "per_topic",
            })
        ```

        ### Rest Route

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main_hub = scaleway.iot.Hub("main",
            name="main",
            product_plan="plan_shared")
        main = scaleway.iot.Route("main",
            name="main",
            hub_id=main_hub.id,
            topic="#",
            rest={
                "verb": "get",
                "uri": "http://scaleway.com",
                "headers": {
                    "X-awesome-header": "my-awesome-value",
                },
            })
        ```

        ## Import

        IoT Routes can be imported using the `{region}/{id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:iot/route:Route route01 fr-par/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param RouteArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RouteArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 database: Optional[pulumi.Input[Union['RouteDatabaseArgs', 'RouteDatabaseArgsDict']]] = None,
                 hub_id: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 rest: Optional[pulumi.Input[Union['RouteRestArgs', 'RouteRestArgsDict']]] = None,
                 s3: Optional[pulumi.Input[Union['RouteS3Args', 'RouteS3ArgsDict']]] = None,
                 topic: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RouteArgs.__new__(RouteArgs)

            __props__.__dict__["database"] = database
            if hub_id is None and not opts.urn:
                raise TypeError("Missing required property 'hub_id'")
            __props__.__dict__["hub_id"] = hub_id
            __props__.__dict__["name"] = name
            __props__.__dict__["region"] = region
            __props__.__dict__["rest"] = rest
            __props__.__dict__["s3"] = s3
            if topic is None and not opts.urn:
                raise TypeError("Missing required property 'topic'")
            __props__.__dict__["topic"] = topic
            __props__.__dict__["created_at"] = None
        alias_opts = pulumi.ResourceOptions(aliases=[pulumi.Alias(type_="scaleway:index/iotRoute:IotRoute")])
        opts = pulumi.ResourceOptions.merge(opts, alias_opts)
        super(Route, __self__).__init__(
            'scaleway:iot/route:Route',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            created_at: Optional[pulumi.Input[_builtins.str]] = None,
            database: Optional[pulumi.Input[Union['RouteDatabaseArgs', 'RouteDatabaseArgsDict']]] = None,
            hub_id: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None,
            rest: Optional[pulumi.Input[Union['RouteRestArgs', 'RouteRestArgsDict']]] = None,
            s3: Optional[pulumi.Input[Union['RouteS3Args', 'RouteS3ArgsDict']]] = None,
            topic: Optional[pulumi.Input[_builtins.str]] = None) -> 'Route':
        """
        Get an existing Route resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] created_at: The date and time the Route was created.
        :param pulumi.Input[Union['RouteDatabaseArgs', 'RouteDatabaseArgsDict']] database: Configuration block for the database routes. See  [product documentation](https://www.scaleway.com/en/docs/iot-hub/how-to/create-route/) for a better understanding of the parameters.
        :param pulumi.Input[_builtins.str] hub_id: The hub ID to which the Route will be attached to.
        :param pulumi.Input[_builtins.str] name: The name of the IoT Route you want to create (e.g. `my-route`).
        :param pulumi.Input[_builtins.str] region: (Defaults to provider `region`) The region in which the Route is attached to.
        :param pulumi.Input[Union['RouteRestArgs', 'RouteRestArgsDict']] rest: Configuration block for the rest routes. See [product documentation](https://www.scaleway.com/en/docs/iot-hub/how-to/create-route/) for a better understanding of the parameters.
        :param pulumi.Input[Union['RouteS3Args', 'RouteS3ArgsDict']] s3: Configuration block for the S3 routes. See [product documentation](https://www.scaleway.com/en/docs/iot-hub/how-to/create-route/) for a better understanding of the parameters.
        :param pulumi.Input[_builtins.str] topic: The topic the Route subscribes to, wildcards allowed (e.g. `thelab/+/temperature/#`).
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RouteState.__new__(_RouteState)

        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["database"] = database
        __props__.__dict__["hub_id"] = hub_id
        __props__.__dict__["name"] = name
        __props__.__dict__["region"] = region
        __props__.__dict__["rest"] = rest
        __props__.__dict__["s3"] = s3
        __props__.__dict__["topic"] = topic
        return Route(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[_builtins.str]:
        """
        The date and time the Route was created.
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter
    def database(self) -> pulumi.Output[Optional['outputs.RouteDatabase']]:
        """
        Configuration block for the database routes. See  [product documentation](https://www.scaleway.com/en/docs/iot-hub/how-to/create-route/) for a better understanding of the parameters.
        """
        return pulumi.get(self, "database")

    @_builtins.property
    @pulumi.getter(name="hubId")
    def hub_id(self) -> pulumi.Output[_builtins.str]:
        """
        The hub ID to which the Route will be attached to.
        """
        return pulumi.get(self, "hub_id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the IoT Route you want to create (e.g. `my-route`).
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        (Defaults to provider `region`) The region in which the Route is attached to.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter
    def rest(self) -> pulumi.Output[Optional['outputs.RouteRest']]:
        """
        Configuration block for the rest routes. See [product documentation](https://www.scaleway.com/en/docs/iot-hub/how-to/create-route/) for a better understanding of the parameters.
        """
        return pulumi.get(self, "rest")

    @_builtins.property
    @pulumi.getter
    def s3(self) -> pulumi.Output[Optional['outputs.RouteS3']]:
        """
        Configuration block for the S3 routes. See [product documentation](https://www.scaleway.com/en/docs/iot-hub/how-to/create-route/) for a better understanding of the parameters.
        """
        return pulumi.get(self, "s3")

    @_builtins.property
    @pulumi.getter
    def topic(self) -> pulumi.Output[_builtins.str]:
        """
        The topic the Route subscribes to, wildcards allowed (e.g. `thelab/+/temperature/#`).
        """
        return pulumi.get(self, "topic")

